@@ -1,8 +1,8 @@
 /* -*- mode:C; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
 /* 
- * This file is part of maemo-af-desktop
+ * This file is part of hildon-desktop
  *
- * Copyright (C) 2005, 2006 Nokia Corporation.
+ * Copyright (C) 2005, 2006, 2007 Nokia Corporation.
  *
  * Contact: Karoliina Salminen <karoliina.t.salminen@nokia.com>
  *
@@ -22,11 +22,22 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <string.h>
 
+#ifdef HAVE_LIBHILDON
+#include <hildon/hildon-defines.h>
+#include <hildon/hildon-banner.h>
+#include <hildon/hildon-note.h>
+#else
 #include <hildon-widgets/hildon-defines.h>
 #include <hildon-widgets/hildon-banner.h>
 #include <hildon-widgets/hildon-note.h>
+#endif
+
 
 #define gettext(o) o
 #define dgettext(o,e) o
@@ -437,6 +448,13 @@ hd_wm_watchable_app_get_name (HDWMWatchableApp *app)
   return app->app_name;
 }
 
+const gchar*
+hd_wm_watchable_app_get_localized_name (HDWMWatchableApp *app)
+{
+  return (app->text_domain?dgettext(app->text_domain,app->app_name):
+                           dgettext("maemo-af-desktop", app->app_name));
+}
+
 const gchar*
 hd_wm_watchable_app_get_icon_name (HDWMWatchableApp *app)
 {
@@ -549,7 +567,7 @@ hd_wm_watchable_app_launch_banner_show (HDWMWatchableApp *app)
                                 APP_LAUNCH_BANNER_MSG_LOADING ),
                               lapp_name ? _(lapp_name) : "" );
         
-  info->banner = GTK_WIDGET(hildon_banner_show_animation(NULL, NULL, info->msg));
+  info->banner = hildon_banner_show_animation(NULL, NULL, info->msg);
   gdk_error_trap_pop();
 
   g_timeout_add(interval, hd_wm_watchable_app_launch_banner_timeout, info);
