@@ -427,7 +427,7 @@ hd_plugin_loader_legacy_home_init (HDPluginLoaderLegacy    *loader,
     return NULL;
   }
 
-  priv->module_data = ((HomeInitializeFn)symbol) (&state_data,
+  priv->module_data = ((HomeInitializeFn)symbol) (state_data,
                                                   &state_data_length,
                                                   &module_widget);
 
@@ -579,6 +579,28 @@ hd_plugin_loader_legacy_navigator_init (HDPluginLoaderLegacy    *loader,
   return item;
 }
 
+typedef void (*SBSetConditional)  (void *data, gboolean cond);
+struct SBSetConditionalData
+{
+  SBSetConditional  cb;
+  gpointer          module_data;
+};
+      
+static void
+hd_plugin_loader_legacy_status_bar_set_conditional 
+                                (HildonDesktopItem           *item,
+                                 GParamSpec *arg1,
+                                 struct SBSetConditionalData *data)
+{
+  gboolean condition;
+  g_object_get (item,
+                "condition", &condition,
+                NULL);
+
+  data->cb (data->module_data, condition);
+}
+                
+
 static GtkWidget *
 hd_plugin_loader_legacy_status_bar_init (HDPluginLoaderLegacy *loader,
                                          GError **error)
@@ -592,7 +614,6 @@ hd_plugin_loader_legacy_status_bar_init (HDPluginLoaderLegacy *loader,
                                      const gchar *str);
 
   typedef int  (*SBGetPriority)     (void *data);
-  typedef void (*SBSetConditional)  (void *data, gboolean cond);
 
   struct SBSymbols
     {
@@ -612,7 +633,7 @@ hd_plugin_loader_legacy_status_bar_init (HDPluginLoaderLegacy *loader,
   gchar            *stripped;
   gchar            *entry_name;
   GKeyFile         *keyfile;
-  struct SBSymbols symbols;
+  struct SBSymbols symbols = {0};
   gpointer          module_data;
   GtkWidget        *module_widget;
   GError           *local_error = NULL;
@@ -669,18 +690,29 @@ hd_plugin_loader_legacy_status_bar_init (HDPluginLoaderLegacy *loader,
 
   if (module_widget)
     {
-      /* FIXME */
-      gtk_widget_set_size_request (module_widget, 40, 40);
-      gtk_widget_show_all (module_widget);
-
       gtk_container_add (GTK_CONTAINER (item), module_widget);
+      gtk_widget_show (module_widget);
     }
 
   g_signal_connect_swapped (item, "destroy",
                             G_CALLBACK (symbols.destroy),
                             module_data);
+  
+  /* FIXME: This is leaked */
+  if (symbols.set_conditional)
+    {
+      struct SBSetConditionalData *set_conditional_data;
 
+      g_object_set (G_OBJECT (item), "condition", FALSE, NULL);
 
+      set_conditional_data = g_new0 (struct SBSetConditionalData, 1);
+      set_conditional_data->cb = (SBSetConditional)symbols.set_conditional;
+      set_conditional_data->module_data = module_data;
+
+      g_signal_connect (item, "notify::condition",
+                        G_CALLBACK (hd_plugin_loader_legacy_status_bar_set_conditional),
+                        set_conditional_data);
+    }
 
   return item;
 
